==> kstars_4.8.5.orig.tar.xz: kstars-4.8.5/kstars/oal/scope.cpp <==
/***************************************************************************
                          scope.cpp  -  description

                             -------------------
    begin                : Wednesday July 8, 2009
    copyright            : (C) 2009 by Prakash Mohan
    email                : prakash.mohan@kdemail.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "oal/scope.h"
void OAL::Scope::setScope( const QString& _id, const QString& _model, const QString& _vendor, const QString& _type, double _focalLength, double _aperture ) {
    m_Id = _id;
    m_Model = _model;
    m_Vendor = _vendor;
    m_Type = _type;
    m_FocalLength = _focalLength;
    m_Aperture = _aperture;
    m_Name.append ( _vendor + ' ' + _model + ' ' + QString::number( _aperture ) + "mm f/" + QString::number( (_focalLength/_aperture), 'g', 1 ) + " (" + _id + ')' ) ; 
}

==> kstars_4.10.2.orig.tar.xz: kstars-4.10.2/kstars/oal/scope.cpp <==
/***************************************************************************
                          scope.cpp  -  description

                             -------------------
    begin                : Wednesday July 8, 2009
    copyright            : (C) 2009 by Prakash Mohan
    email                : prakash.mohan@kdemail.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "oal/scope.h"
void OAL::Scope::setScope( const QString& _id, const QString& _model, const QString& _vendor, const QString& _type, double _focalLength, double _aperture ) {
    m_Id = _id;
    m_Model = _model;
    m_Vendor = _vendor;
    m_Type = _type;
    m_FocalLength = _focalLength;
    m_Aperture = _aperture;
    //m_Name.append ( _vendor + ' ' + _model + ' ' + QString::number( _aperture ) + "mm f/" + QString::number( (_focalLength/_aperture), 'g', 1 ) + " (" + _id + ')' ) ;

    m_Name = _vendor + " " + _model + " (" + _id + ")" ;
}
